pub struct ConnectionType(/* private fields */);Implementations
Sourceimpl ConnectionType
impl ConnectionType
Sourcepub const NODE: ConnectionType
pub const NODE: ConnectionType
Represents the fuchsia.io/Node protocol.
Sourcepub const CONTROLLER: ConnectionType
pub const CONTROLLER: ConnectionType
Represents the fuchsia.device/Controller protocol.
Sourcepub const DEVICE: ConnectionType
pub const DEVICE: ConnectionType
Represents the device specific FIDL.
Sourceimpl ConnectionType
impl ConnectionType
Sourcepub const fn empty() -> ConnectionType
pub const fn empty() -> ConnectionType
Get a flags value with all bits unset.
Sourcepub const fn all() -> ConnectionType
pub const fn all() -> ConnectionType
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<ConnectionType>
pub const fn from_bits(bits: u8) -> Option<ConnectionType>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> ConnectionType
pub const fn from_bits_truncate(bits: u8) -> ConnectionType
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> ConnectionType
pub const fn from_bits_retain(bits: u8) -> ConnectionType
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ConnectionType>
pub fn from_name(name: &str) -> Option<ConnectionType>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ConnectionType) -> bool
pub const fn intersects(&self, other: ConnectionType) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ConnectionType) -> bool
pub const fn contains(&self, other: ConnectionType) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ConnectionType)
pub fn insert(&mut self, other: ConnectionType)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ConnectionType)
pub fn remove(&mut self, other: ConnectionType)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ConnectionType)
pub fn toggle(&mut self, other: ConnectionType)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ConnectionType, value: bool)
pub fn set(&mut self, other: ConnectionType, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ConnectionType) -> ConnectionType
pub const fn intersection(self, other: ConnectionType) -> ConnectionType
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: ConnectionType) -> ConnectionType
pub const fn union(self, other: ConnectionType) -> ConnectionType
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: ConnectionType) -> ConnectionType
pub const fn difference(self, other: ConnectionType) -> ConnectionType
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ConnectionType) -> ConnectionType
pub const fn symmetric_difference(self, other: ConnectionType) -> ConnectionType
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ConnectionType
pub const fn complement(self) -> ConnectionType
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ConnectionType
impl ConnectionType
Sourcepub const fn iter(&self) -> Iter<ConnectionType>
pub const fn iter(&self) -> Iter<ConnectionType>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ConnectionType>
pub const fn iter_names(&self) -> IterNames<ConnectionType>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ConnectionType
impl ConnectionType
pub fn from_bits_allow_unknown(bits: u8) -> ConnectionType
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u8