pub struct ConnectorProxy { /* private fields */ }Implementations
Sourceimpl ConnectorProxy
impl ConnectorProxy
Sourcepub fn take_event_stream(&self) -> ConnectorEventStream
pub fn take_event_stream(&self) -> ConnectorEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn connect(&self, server: Channel) -> Result<(), Error>
pub fn connect(&self, server: Channel) -> Result<(), Error>
Forward a server end of a protocol so that it can be connected.
- request
serverthe server end of the protocol to be served. The FIDL protocol that this speaks is determined out-of-band.
- response This function has no response. The function is one-way to match the pipelining behaviors of other virtual filesystems.